<?php
/**
 * Gestion du formulaire de d'édition de Vimeo
 *
 * @plugin     Vimeo
 * @copyright  2017-2021
 * @author     Charles Stephan
 * @licence    GNU/GPL
 * @package    SPIP\Vimeo\Formulaires
 */

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

include_spip('inc/actions');
include_spip('inc/editer');

/**
 * Identifier le formulaire en faisant abstraction des paramètres qui ne représentent pas l'objet edité
 *
 * @param  int|string  $id_vimeo
 *     Identifiant du vimeo. 'new' pour un nouveau vimeo.
 * @param  string  $retour
 *     URL de redirection après le traitement
 * @param  int  $lier_trad
 *     Identifiant éventuel d'un vimeo source d'une traduction
 * @param  string  $config_fonc
 *     Nom de la fonction ajoutant des configurations particulières au formulaire
 * @param  array  $row
 *     Valeurs de la ligne SQL du vimeo, si connu
 * @param  string  $hidden
 *     Contenu HTML ajouté en même temps que les champs cachés du formulaire.
 *
 * @return string
 *     Hash du formulaire
 */
function formulaires_editer_vimeo_identifier_dist(
	$id_vimeo = 'new',
	$retour = '',
	$lier_trad = 0,
	$config_fonc = '',
	$row = array(),
	$hidden = ''
) {
	return serialize(array(intval($id_vimeo)));
}

/**
 * Chargement du formulaire d'édition de vimeo
 *
 * Déclarer les champs postés et y intégrer les valeurs par défaut
 *
 * @param  int|string  $id_vimeo
 *     Identifiant du vimeo. 'new' pour un nouveau vimeo.
 * @param  string  $retour
 *     URL de redirection après le traitement
 * @param  int  $lier_trad
 *     Identifiant éventuel d'un vimeo source d'une traduction
 * @param  string  $config_fonc
 *     Nom de la fonction ajoutant des configurations particulières au formulaire
 * @param  array  $row
 *     Valeurs de la ligne SQL du vimeo, si connu
 * @param  string  $hidden
 *     Contenu HTML ajouté en même temps que les champs cachés du formulaire.
 *
 * @return array
 *     Environnement du formulaire
 * @uses formulaires_editer_objet_charger()
 *
 */
function formulaires_editer_vimeo_charger_dist(
	$id_vimeo = 'new',
	$retour = '',
	$lier_trad = 0,
	$config_fonc = '',
	$row = array(),
	$hidden = ''
) {
	$valeurs = formulaires_editer_objet_charger('vimeo', $id_vimeo, '', $lier_trad, $retour, $config_fonc, $row,
		$hidden);
	return $valeurs;
}

/**
 * Vérifications du formulaire d'édition de vimeo
 *
 * Vérifier les champs postés et signaler d'éventuelles erreurs
 *
 * @param  int|string  $id_vimeo
 *     Identifiant du vimeo. 'new' pour un nouveau vimeo.
 * @param  string  $retour
 *     URL de redirection après le traitement
 * @param  int  $lier_trad
 *     Identifiant éventuel d'un vimeo source d'une traduction
 * @param  string  $config_fonc
 *     Nom de la fonction ajoutant des configurations particulières au formulaire
 * @param  array  $row
 *     Valeurs de la ligne SQL du vimeo, si connu
 * @param  string  $hidden
 *     Contenu HTML ajouté en même temps que les champs cachés du formulaire.
 *
 * @return array
 *     Tableau des erreurs
 * @uses formulaires_editer_objet_verifier()
 *
 */
function formulaires_editer_vimeo_verifier_dist(
	$id_vimeo = 'new',
	$retour = '',
	$lier_trad = 0,
	$config_fonc = '',
	$row = array(),
	$hidden = ''
) {
	$erreurs = array();

	$erreurs = formulaires_editer_objet_verifier('vimeo', $id_vimeo, array('url_video', 'titre'));

	return $erreurs;
}

/**
 * Traitement du formulaire d'édition de vimeo
 *
 * Traiter les champs postés
 *
 * @param  int|string  $id_vimeo
 *     Identifiant du vimeo. 'new' pour un nouveau vimeo.
 * @param  string  $retour
 *     URL de redirection après le traitement
 * @param  int  $lier_trad
 *     Identifiant éventuel d'un vimeo source d'une traduction
 * @param  string  $config_fonc
 *     Nom de la fonction ajoutant des configurations particulières au formulaire
 * @param  array  $row
 *     Valeurs de la ligne SQL du vimeo, si connu
 * @param  string  $hidden
 *     Contenu HTML ajouté en même temps que les champs cachés du formulaire.
 *
 * @return array
 *     Retours des traitements
 * @uses formulaires_editer_objet_traiter()
 *
 */
function formulaires_editer_vimeo_traiter_dist(
	$id_vimeo = 'new',
	$retour = '',
	$lier_trad = 0,
	$config_fonc = '',
	$row = array(),
	$hidden = ''
) {
	$retours = formulaires_editer_objet_traiter('vimeo', $id_vimeo, '', $lier_trad, $retour, $config_fonc, $row,
		$hidden);
	return $retours;
}
